// vim:set noet cinoptions= sw=4 ts=4:
// This file is part of the eix project and distributed under the
// terms of the GNU General Public License v2.
//
// Copyright (c)
//   Wolfgang Frisch <xororand@users.sourceforge.net>
//   Emil Beinroth <emilbeinroth@gmx.net>
//   Martin Väth <martin@mvath.de>

#include <config.h>  // IWYU pragma: keep

#define EIX_BINARY 1
#define DIFF_BINARY 1
#define UPDATE_BINARY 1
#define HEADER_BINARY 1
#define DROP_PERMISSIONS_BINARY 1
#define VERSIONSORT_BINARY 1
#define MASKED_BINARY 1
#include "main/main.cc"  // NOLINT(build/include)
